@@ -12,7 +12,7 @@ MAX_NFEV_DFT = 100
 PARAMS = "params"
 # Kwargs
 LOGGER = "logger"
-# Dataframe columns
+# Column names
 COUNT = "count"
 FOLD = "fold"
 MEAN = "mean"
@@ -21,5 +21,9 @@ PARAMETER = "parameter"
 RSQ = "rsq"
 SCORE = "score"
 STD = "std"
+TIME = "time"
 TRUE = "true"
 VALUE = "value"
+# Parameter class
+PARAMETER_LOWER_BOUND = 0
+PARAMETER_UPPER_BOUND = 10
